"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useResizeObserver = void 0;
const react_1 = require("react");
// avoid using useLayoutEffect in a node.js process to avoid SSR warnings.
const useEarliestEffect = typeof window !== "undefined" ? react_1.useLayoutEffect : react_1.useEffect;
function useResizeObserver(onResize) {
    // We don't want to re-create the ResizeObserver every time the onResize callback
    // changes. So we use the last recommendation for effect dependencies changing too often:
    // https://reactjs.org/docs/hooks-faq.html#what-can-i-do-if-my-effect-dependencies-change-too-often
    //
    // This would be a good use case for the useEvent rfc (https://github.com/reactjs/rfcs/pull/220).
    const refCallback = (0, react_1.useRef)(onResize);
    useEarliestEffect(() => {
        refCallback.current = onResize;
    });
    const refResizeObserver = (0, react_1.useRef)();
    // Return a stable getter that lazily creates the resize observer:
    // https://reactjs.org/docs/hooks-faq.html#how-to-create-expensive-objects-lazily
    //
    // This probably needs to be stable because it will often be used in reference callbacks:
    // https://reactjs.org/docs/hooks-faq.html#how-can-i-measure-a-dom-node
    const getResizeObserver = (0, react_1.useCallback)(() => {
        if (!refResizeObserver.current) {
            refResizeObserver.current = new ResizeObserver((entries, ro) => {
                refCallback.current(entries, ro);
            });
        }
        return refResizeObserver.current;
    }, []);
    return [getResizeObserver, refResizeObserver];
}
exports.useResizeObserver = useResizeObserver;
